@@ -29,9 +29,9 @@ class BinningDimCombiner():
 
 
 def handle_one_df(df, query=None, replacements=[],
-                  combine_dims=[], combine_dims_ignore=None, combine_delim="__"):
+                  combine_dims=[], combine_dims_ignore=None, combine_delim="__", engine_query=None):
     if query:
-        df.query(query, inplace=True)
+        df.query(query, inplace=True, engine=engine_query)
     if df.empty:
         return
     df.drop(df.filter(like="Unnamed").columns, axis=1, inplace=True)
@@ -51,13 +51,13 @@ def handle_one_df(df, query=None, replacements=[],
     return df
 
 
-def query(df, query):
+def query(df, query, engine=None):
     """
     Keep only rows that satisfy requirements of the query string,
     See: https://pandas.pydata.org/pandas-docs/stable/reference/api/pandas.DataFrame.query.html
     """
     logger.info("Applying query: %s", query)
-    return handle_one_df(df, query=query)
+    return handle_one_df(df, query=query, engine_query=engine)
 
 
 def rebin(df, axis, mapping, ignore_when_combining=None, rename=None, drop_others=False):
@@ -382,11 +382,11 @@ def assign_dim(df, assignments={}, evals={}, drop_cols=[]):
     return df
 
 
-def merge(dfs):
+def merge(dfs, sort=True):
     """ Merge a list of binned dataframes together
     """
     logger.info("Merging %d dataframes", len(dfs))
-    final_df = pd.concat(dfs, sort=True)  # .fillna(float("-inf"))
+    final_df = pd.concat(dfs, sort=sort)  # .fillna(float("-inf"))
     final_df = final_df.groupby(level=final_df.index.names).sum()  # .replace(float("-inf"), float("nan"))
     return final_df
 
@@ -446,7 +446,7 @@ def normalise_group(df, groupby_dimensions, apply_if=None, use_column=None):
     return normed
 
 
-def open_many(file_list, value_columns=r"(.*sumw2?|n)", return_meta=True):
+def open_many(file_list, value_columns=r"(.*sumw2?|^n$)", return_meta=True):
     """ Open a list of dataframe files
     """
     dfs = []
